@@ -3,7 +3,9 @@ from __future__ import unicode_literals
 from itertools import islice
 
 from django_countries.conf import settings
+from django.utils import six
 from django.utils.encoding import force_text
+from django.utils.translation import override
 
 try:
     import pyuca
@@ -30,31 +32,60 @@ class Countries(object):
     code and name), sorted by name.
     """
 
+    def get_option(self, option):
+        """
+        Get a configuration option, trying the options attribute first and
+        falling back to a Django project setting.
+        """
+        value = getattr(self, option, None)
+        if value is not None:
+            return value
+        return getattr(settings, 'COUNTRIES_{0}'.format(option.upper()))
+
     @property
     def countries(self):
         """
         Return the a dictionary of countries, modified by any overriding
-        settings.
+        options.
 
         The result is cached so future lookups are less work intensive.
         """
         if not hasattr(self, '_countries'):
-            if settings.COUNTRIES_ONLY:
-                self._countries = dict(settings.COUNTRIES_ONLY)
+            only = self.get_option('only')
+            if only:
+                only_choices = True
+                if not isinstance(only, dict):
+                    for item in only:
+                        if isinstance(item, six.string_types):
+                            only_choices = False
+                            break
+            if only and only_choices:
+                self._countries = dict(only)
             else:
                 # Local import so that countries aren't loaded into memory
                 # until first used.
                 from django_countries.data import COUNTRIES, COMMON_NAMES
                 self._countries = dict(COUNTRIES)
-                if settings.COUNTRIES_COMMON_NAMES:
+                if self.get_option('common_names'):
                     self._countries.update(COMMON_NAMES)
-                if settings.COUNTRIES_OVERRIDE:
-                    self._countries.update(settings.COUNTRIES_OVERRIDE)
+                override = self.get_option('override')
+                if override:
+                    self._countries.update(override)
                     self._countries = dict(
                         (code, name) for code, name in self._countries.items()
                         if name is not None)
+            if only and not only_choices:
+                countries = {}
+                for item in only:
+                    if isinstance(item, six.string_types):
+                        countries[item] = self._countries[item]
+                    else:
+                        key, value = item
+                        countries[key] = value
+                self._countries = countries
             self.countries_first = []
-            for code in settings.COUNTRIES_FIRST:
+            first = self.get_option('first') or []
+            for code in first:
                 code = self.alpha2(code)
                 if code in self._countries:
                     self.countries_first.append(code)
@@ -71,8 +102,9 @@ class Countries(object):
     @countries.deleter
     def countries(self):
         """
-        Reset the countries cache in case for some crazy reason the settings
-        change. But surely no one is crazy enough to do that, right?
+        Reset the countries cache in case for some crazy reason the settings or
+        internal options change. But surely no one is crazy enough to do that,
+        right?
         """
         if hasattr(self, '_countries'):
             del self._countries
@@ -94,18 +126,23 @@ class Countries(object):
         The first countries can be separated from the sorted list by the value
         provided in ``settings.COUNTRIES_FIRST_BREAK``.
         """
+        # Initializes countries_first, so needs to happen first.
+        countries = self.countries
+
         # Yield countries that should be displayed first.
         for code in self.countries_first:
-            yield (code, force_text(self.countries[code]))
+            yield (code, force_text(countries[code]))
 
-        if (self.countries_first and settings.COUNTRIES_FIRST_BREAK):
-            yield ('', force_text(settings.COUNTRIES_FIRST_BREAK))
+        if self.countries_first:
+            first_break = self.get_option('first_break')
+            if first_break:
+                yield ('', force_text(first_break))
 
         # Force translation before sorting.
+        first_repeat = self.get_option('first_repeat')
         countries = [
-            (code, force_text(name)) for code, name in self.countries.items()
-            if settings.COUNTRIES_FIRST_REPEAT
-            or code not in self.countries_first]
+            (code, force_text(name)) for code, name in countries.items()
+            if first_repeat or code not in self.countries_first]
 
         # Return sorted country list.
         for item in sorted(countries, key=sort_key):
@@ -146,6 +183,21 @@ class Countries(object):
         code = self.alpha2(code)
         return self.countries.get(code, '')
 
+    def by_name(self, country, language='en'):
+        """
+        Fetch a country's ISO3166-1 two letter country code from its name.
+
+        An optional language parameter is also available.
+        Warning: This depends on the quality of the available translations.
+
+        If no match is found, returns an empty string.
+        """
+        with override(language):
+            for code, name in self:
+                if name == country:
+                    return code
+        return ''
+
     def alpha3(self, code):
         """
         Return the ISO 3166-1 three letter country code matching the provided
@@ -186,7 +238,7 @@ class Countries(object):
         count = len(self.countries)
         # Add first countries, and the break if necessary.
         count += len(self.countries_first)
-        if self.countries_first and settings.COUNTRIES_FIRST_BREAK:
+        if self.countries_first and self.get_option('first_break'):
             count += 1
         return count
 
