@@ -8,23 +8,46 @@ except ImportError:
 from django import forms
 from django.db.models.fields import CharField, BLANK_CHOICE_DASH
 from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.html import escape as escape_html
 from django.utils.functional import lazy
 
 from django_countries import countries, ioc_data, widgets
 from django_countries.conf import settings
 
 
+class TemporaryEscape(object):
+    __slots__ = ['country', 'original_escape']
+
+    def __init__(self, country):
+        self.country = country
+
+    def __bool__(self):
+        return self.country._escape
+
+    __nonzero__ = __bool__
+
+    def __enter__(self):
+        self.original_escape = self.country._escape
+        self.country._escape = True
+
+    def __exit__(self, type, value, traceback):
+        self.country._escape = self.original_escape
+
+
 @python_2_unicode_compatible
 class Country(object):
-    def __init__(self, code, flag_url=None):
+
+    def __init__(self, code, flag_url=None, str_attr='code'):
         self.code = code
         self.flag_url = flag_url
+        self._escape = False
+        self._str_attr = str_attr
 
     def __str__(self):
-        return force_text(self.code or '')
+        return force_text(getattr(self, self._str_attr) or '')
 
     def __eq__(self, other):
-        return force_text(self) == force_text(other or '')
+        return force_text(self.code or '') == force_text(other or '')
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -33,12 +56,13 @@ class Country(object):
         return hash(force_text(self))
 
     def __repr__(self):
-        if self.flag_url is None:
-            repr_text = "{0}(code={1})"
-        else:
-            repr_text = "{0}(code={1}, flag_url={2})"
-        return repr_text.format(
-            self.__class__.__name__, repr(self.code), repr(self.flag_url))
+        args = ['code={country.code!r}']
+        if self.flag_url is not None:
+            args.append('flag_url={country.flag_url!r}')
+        if self._str_attr != 'code':
+            args.append('str_attr={country._str_attr!r}')
+        args = ', '.join(args).format(country=self)
+        return '{name}({args})'.format(name=self.__class__.__name__, args=args)
 
     def __bool__(self):
         return bool(self.code)
@@ -48,9 +72,18 @@ class Country(object):
     def __len__(self):
         return len(force_text(self))
 
+    @property
+    def escape(self):
+        return TemporaryEscape(self)
+
+    def maybe_escape(self, text):
+        if not self.escape:
+            return text
+        return escape_html(text)
+
     @property
     def name(self):
-        return countries.name(self.code)
+        return self.maybe_escape(countries.name(self.code))
 
     @property
     def alpha3(self):
@@ -73,7 +106,10 @@ class Country(object):
             flag_url = settings.COUNTRIES_FLAG_URL
         url = flag_url.format(
             code_upper=self.code, code=self.code.lower())
-        return urlparse.urljoin(settings.STATIC_URL, url)
+        if not url:
+            return ''
+        url = urlparse.urljoin(settings.STATIC_URL, url)
+        return self.maybe_escape(url)
 
     @staticmethod
     def country_from_ioc(ioc_code, flag_url=''):
@@ -142,11 +178,13 @@ class CountryField(CharField):
     descriptor_class = CountryDescriptor
 
     def __init__(self, *args, **kwargs):
+        countries_class = kwargs.pop('countries', None)
+        self.countries = countries_class() if countries_class else countries
         self.countries_flag_url = kwargs.pop('countries_flag_url', None)
         self.blank_label = kwargs.pop('blank_label', None)
         kwargs.update({
             'max_length': 2,
-            'choices': countries,
+            'choices': self.countries,
         })
         super(CharField, self).__init__(*args, **kwargs)
 
@@ -184,6 +222,10 @@ class CountryField(CharField):
         """
         name, path, args, kwargs = super(CountryField, self).deconstruct()
         kwargs.pop('choices')
+        if self.countries is not countries:
+            # Include the countries class if it's not the default countries
+            # instance.
+            kwargs['countries'] = self.countries.__class__
         return name, path, args, kwargs
 
     def get_choices(
