@@ -100,7 +100,7 @@ IOC_TO_ISO = {
     'KEN': 'KE',
     'KGZ': 'KG',
     'KIR': 'KI',
-    'KOR': 'KP',
+    'KOR': 'KR',
     'KSA': 'SA',
     'KUW': 'KW',
     'LAO': 'LA',
@@ -151,7 +151,7 @@ IOC_TO_ISO = {
     'PNG': 'PG',
     'POL': 'PL',
     'POR': 'PT',
-    'PRK': 'KR',
+    'PRK': 'KP',
     'PUR': 'PR',
     'QAT': 'QA',
     'ROU': 'RO',
