@@ -2,7 +2,8 @@
 from __future__ import unicode_literals
 from django.test import TestCase
 
-from django_countries import countries
+from django_countries import countries, Countries
+from django_countries.tests import custom_countries
 
 
 EXPECTED_COUNTRY_COUNT = 249
@@ -39,6 +40,14 @@ class TestCountriesObject(BaseTest):
             ])
             self.assertEqual(len(countries), 2)
 
+    def test_countries_limit_codes(self):
+        with self.settings(COUNTRIES_ONLY=['NZ', ('NV', 'Neverland')]):
+            self.assertEqual(list(countries), [
+                ('NV', 'Neverland'),
+                ('NZ', 'New Zealand'),
+            ])
+            self.assertEqual(len(countries), 2)
+
     def test_countries_custom_removed_len(self):
         with self.settings(COUNTRIES_OVERRIDE={'AU': None}):
             self.assertEqual(len(countries), EXPECTED_COUNTRY_COUNT - 1)
@@ -70,6 +79,10 @@ class TestCountriesObject(BaseTest):
         from ..ioc_data import check_ioc_countries
         check_ioc_countries(verbosity=0)
 
+    def test_initial_iter(self):
+        # Use a new instance so nothing is cached
+        dict(Countries())
+
     def test_flags(self):
         from ..data import check_flags
         check_flags(verbosity=0)
@@ -96,6 +109,17 @@ class TestCountriesObject(BaseTest):
         with self.settings(COUNTRIES_OVERRIDE={'XX': 'Neverland'}):
             self.assertEqual(countries.alpha2('XX'), 'XX')
 
+    def test_fetch_by_name(self):
+        code = countries.by_name('United States of America')
+        self.assertEqual(code, 'US')
+
+    def test_fetch_by_name_i18n(self):
+        code = countries.by_name('Estados Unidos', language='es')
+        self.assertEqual(code, 'US')
+
+    def test_fetch_by_name_no_match(self):
+        self.assertEqual(countries.by_name('Neverland'), '')
+
 
 class CountriesFirstTest(BaseTest):
 
@@ -161,3 +185,14 @@ class CountriesFirstTest(BaseTest):
         with self.settings(COUNTRIES_FIRST=['XX'],
                            COUNTRIES_FIRST_BREAK='------'):
             self.assertEqual(len(countries), EXPECTED_COUNTRY_COUNT)
+
+
+class TestCountriesCustom(BaseTest):
+
+    def test_countries_limit(self):
+        fantasy_countries = custom_countries.FantasyCountries()
+        self.assertEqual(list(fantasy_countries), [
+            ('NV', 'Neverland'),
+            ('NZ', 'New Zealand'),
+        ])
+        self.assertEqual(len(fantasy_countries), 2)
